# List Umbreo Command CLI

### We have 2 ways to call action command:

* command-suite
* command-form

### Wiki Umbreo Command CLI

1. [Endpoint Configuration](#1-endpoint-configuration)
2. [Authentication](#2-authentication)
	* [Login](#login)
	* [Logout](#logout)
3. [Instance](#3-instance)
	* [List or filter](#list-or-filter)
	* [Search](#search)
	* [Show detail](#show-detail)
	* [Deploy Blueprint](#deploy-blueprint)
4. [Module](#4-module)
	* [List](#list)
	* [Search](#search-1)
5. [Profile](#5-profile)
	* [List](#list-1)
	* [Search](#search-2)
6. [System](#6-system)
	* [List](#list-2)
7. [Blueprint](#7-blueprint)
	* [List or filter](#list-or-filter-1)
	* [Search](#search-3)
	* [Show detail](#show-detail-1)
	* [Delete my custom blueprint](#delete-my-custom-blueprint)
	* [Create custom blueprint](#create-custom-blueprint)
	* [Deploy blueprint](#deploy-blueprint)
	* [Export blueprint json](#export-blueprint-json)
	* [Validate blueprint json](#validate-blueprint-json)
8. [Stack Template](#8-stack-template)
	* [List or filter](#list-or-filter-2)
	* [Search](#search-4)
	* [Show detail](#show-detail-2)
    * [Export stack template json](#export-stack-template-json)
	* [Export blueprints of stack template json](#export-blueprinst-of-stack-template-json)
9. [Stack](#9-stack)
	* [List](#list-3)
	* [Search](#search-5)
	* [Show detail](#show-detail-3)
	* [Create stack](#create-stack)
10. [Cloud Provider](#10-cloud-provider)
	* [List](#list-4)
	* [Export cloud provider json](#export-cloud-provider-json)
	* [Validate cloud provider json](#validate-cloud-provider-json)
11. [Provider](#11-provider)
	* [List or filter](#list-or-filter-3)
	* [Search](#search-6)
	* [Show detail](#show-detail-4)
	* [Create provider](#create-provider)
	* [Get Data Credential](#get-data-credential)
12. [Service Provider](#12-service-provider)
	* [List or filter](#list-or-filter-4)
	* [Search](#search-7)
	* [Show detail](#show-detail-5)
	* [Export service provider json](#export-service-provider-json)
	* [Validate service provider json](#validate-service-provider-json)
13. [Service](#13-service)
	* [List or filter](#list-or-filter-5)
	* [Search](#search-8)
	* [Show detail](#show-detail-6)
	* [Create Service](#create-service)
	* [Export service json](#export-service-json)
	* [Validate service json](#validate-service-json)

Getting Started 
====================
This guide will help you to setup and run CLI

# Step1: install bundler
```ruby
$ gem install bundler
```

# Step2: Run bundle install
```console
$ bundle install
```

# How to Run CLI
## You can simply go run this command
### For first time
```console
$ bundle exec bin/umbreo [command] [arg]
```

### For secondtime
```console
$ umbreo [command] [arg]
```

# Below are current lists command on CLI

## 1. Endpoint Configuration

We can switch host endpoint for development mode

#### command-suite
```console
$ umbreo endpoint configure --url endpoint_url
```
```console
$ umbreo endpoint configure --url https://beta.umbreo.com
```
#### command-form
```console
$ umbreo endpoint configure
$ Enter your Endpoint (URL): https://beta.umbreo.com
```
#### output
```console
{:email=>"", :api_key=>"", :name=>"", :end_point=>"https://beta.umbreo.com"}
End point updated, you have to resign in to your app.
```

## 2. Authentication

### Login

File Credential will be created on ~/.umbreoconfig file

#### command-suite
```console
$ umbreo login --email your_email --password your_password
```
```console
$ umbreo login --email foo@umbreo.com --password foobar
```

#### command-form
```console
$ umbreo endpoint login

Enter your Umbreo credentials.
$ Email: foobar@umbreo.com 
$ Password (Typing will be hidden):
```

#### output
```console
Setting up configuration file at ~/.umbreoconfig...
{:email=>"foo@umbreo.com", :api_key=>"EangroBEk_**_**", :name=>"foobar", :end_point=>"https://beta.umbreo.com"}
Logged in as foo@umbreo.com
```

### Logout
```console
$ umbreo logout
Local credentials cleared.
```

## 3. Instance

### List or filter

#### command-suite
```console
$ umbreo instance list --register_type |all|registered|unregistered| --type |all|test|manual|provider| --cloud |aws|gcompute|docean|openstack|XenServer| --page |number_of_page|
```
```console
$ umbreo instance list --register_type all --type test --cloud aws --page 2
```

#### command-form
```console
$ umbreo instance list

1. all
2. registered
3. unregistered
$ Please choose filter of register type? all

1. all
2. test
3. manual
4. provider
$ Please choose filter of instance deployment type? test
```

#### output
```console
+-------+------------------+----------+-------------+
|            List My Instance | Page: 1             |
+-------+------------------+----------+-------------+
| ID    | Name             | Hostname | Description |
+-------+------------------+----------+-------------+
| 61    | Instance1        | ?        |             |
| 62    | Instance2        | ?        | test        |
| 63    | Instance3        | ?        | test        |
| 64    | Instance4        | ?        | test        |
| 65    | Instance5        | ?        | test        |
| 66    | Instance6        | ?        |             |
+-------+------------------+----------+-------------+
```

### Search

#### command-suite
```console
$ umbreo instance search --keyword |search_keyword| --register_type |all|registered|unregistered| --type |all|test|manual|provider| --cloud |aws|gcompute|docean|openstack|XenServer| --page |number_of_page|
```
```console
$ umbreo instance search --keyword 'Foo Instance' --register_type all --type test --cloud aws
```

#### command-form
```console
$ umbreo instance search

1. all
2. registered
3. unregistered
$ Please choose filter of register type? all

1. all
2. test
3. manual
4. provider
$ Please choose filter of instance deployment type? test

$ Search keyword: Foo Instance
```

#### output
```console
+----+------------------+----------+-------------+
|                List My Instance                |
+----+------------------+----------+-------------+
| ID | Name             | Hostname | Description |
+----+------------------+----------+-------------+
| 61 | Foo Instance     | ?        |             |
+----+------------------+----------+-------------+
```

### Show detail

#### command-suite
```console
$ umbreo instance show --id |id_or_name|
```
```console
$ umbreo instance show --id 'foo instance'
```

#### command-form
```console
$ umbreo instance show
$ Name or ID of Instance: foo instance
```

#### output
```console
ID: 61
Name: Foo Instance
Description: 
Blueprint: Apache Webserver with PHP
Deployment type: provider
Hostname: ?
Created At: 2016-07-09
```

### Deploy Blueprint

#### command-suite
```console
$ umbreo instance deploy --custom |optional_to_get_custom_or_umbreo_blueprints| --name |name_of_instance| --desc |desc_of_instance| --blueprint |directory_blueprint_json_file| --service_logging |directory_my_service_logging_json_file| --service_monitoring |directory_service_monitoring_json_file| --service_backup |directory_service_backup_json_file| --type |test|manual|provider| --provider |directory_my_provider_json_file|
```
```console
$ umbreo instance deploy --name 'Foo Instance' --desc 'My first instance' --type provider --blueprint apache_webserver_with_php.json --provider digital_ocean_provider.json --service_backup baculaexternal.json
```

#### command-form
```console
$ umbreo instance deploy --custom

$ Name of new instance: Foo Instance
$ Description of new instance: My First instance
$ Blueprint directory File JSON: custom_apache_webserver_with_php.json
$ Service logging directory File JSON (optional): 
$ Service monitoring directory File JSON (optional): 
$ Service backup directory File JSON (optional): 

1. test
2. manual
3. provider
$ Please choose deployment type? 1

```

#### output
```console
Instance foo instance successfully created
```

## 4. Module

All command that's associated to Module

### List

#### command-suite
```console
$ umbreo module list --page |number_of_page|
```
```console
$ umbreo module list
```

#### output
```console
+-----------+--------------+-------------+
|    List Module | Page: 1 of 2 pages    |
+-----------+--------------+-------------+
| ID        | Name         | Description |
+-----------+--------------+-------------+
| 1         | php          |             |
| 3         | tomcat       |             |
| 4         | jetty        |             |
| 6         | postgresql   |             |
| 8         | jenkins      |             |
| 13        | mongodb      |             |
| 19        | apache       |             |
| 20        | rails        |             |
+-----------+--------------+-------------+
```

### Search

#### command-suite
```console
$ umbreo module search --keyword |search_keyword| --page |number_of_page|
```
```console
$ umbreo module search --keyword php
```

#### output
```console
+-----------+--------------+-------------+
|    List Module | Page: 1 of 2 pages    |
+-----------+--------------+-------------+
| ID        | Name         | Description |
+-----------+--------------+-------------+
| 1         | php          |             |
+-----------+--------------+-------------+
```

## 5. Profile

All command that's associated to Profile

### List

#### command-suite
```console
$ umbreo profile list --page |number_of_page|
```
```console
$ umbreo profile list
```

#### output
```console
+-----------+----------------+-------------+
|    List Profile | Page: 1 of 3 pages     |
+-----------+----------------+-------------+
| ID        | Name           | Description |
+-----------+----------------+-------------+
| 1         | rails          |             |
| 34        | msvisualstudio | for windows |
| 35        | mssql          | for windows |
| 36        | jdk7           | for windows |
| 37        | jdk8           | for windows |
+-----------+----------------+-------------+
```

### Search

#### command-suite
```console
$ umbreo profile search --keyword |search_keyword| --page |number_of_page|
```
```console
$ umbreo profile search --keyword rails
```

#### output
```console
+-----------+----------------+-------------+
|    List Profile | Page: 1 of 3 pages     |
+-----------+----------------+-------------+
| ID        | Name           | Description |
+-----------+----------------+-------------+
| 1         | rails          |             |
+-----------+----------------+-------------+
```

## 6. System

### List

#### command-suite
```console
$ umbreo system list
```

#### output
```console
+------+--------------+
|     List System     |
+------+--------------+
| ID   | Name         |
+------+--------------+
| 1    | Ubuntu       |
| 2    | CentOS       |
| 3    | Fedora       |
| 4    | Ubuntu 12.04 |
| 5    | Ubuntu 14.04 |
| 6    | CentOS 5     |
| 7    | CentOS 6     |
| 8    | CentOS 7     |
| 9    | Fedora 19    |
| 10   | Fedora 20    |
| 11   | Ubuntu 10.04 |
| 12   | Windows      |
+------+--------------+
```

## 7. Blueprint

All command that's associated to Blueprint

### List or filter

#### command-suite
```console
$ umbreo blueprint list --custom |optional_to_get_custom_or_umbreo_blueprints| --os |all|linux|windows| --page |number_of_page|
```
```console
$ umbreo blueprint list --os all
```

#### command-form
```console
$ umbreo blueprint list

1. all
2. linux
3. windows
$ Please choose filter of instance provider? all
```

#### output
```console
+-------+-----------------------------+----------------------------+---------+--------------------------------+
|                                     List Blueprint | Page: 1 of 3 pages                                     |
+-------+-----------------------------+----------------------------+---------+--------------------------------+
| ID    | Name                        | Slug                       | OS      | Description                    |
+-------+-----------------------------+----------------------------+---------+--------------------------------+
| 3     | LAMP Server                 | lamp-server                | linux   |                                |
| 4     | Apache Webserver with PHP   | apache-webserver-with-php  | linux   | Apache Webserver with PHP S... |
| 5     | Apache Webserver            | apache-webserver           | linux   | A standard Apache Webserver.   |
| 6     | Postgresql Server           | postgresql-server          | linux   |                                |
| 8     | Tomcat Application Server   | tomcat-application-server  | linux   |                                |
| 9     | Jetty Application Server    | jetty-application-server   | linux   | Jetty Application Server, a... |
| 10    | Rails, Apache and Passenger | rails-apache-and-passenger | linux   | This blueprint will set-up ... |
| 13    | Jenkins CI Server           | jenkins-ci-server          | linux   |                                |
| 17    | Docker                      | docker                     | linux   |                                |
| 18    | NodeJS                      | nodejs                     | linux   |                                |
+-------+-----------------------------+----------------------------+---------+--------------------------------+
```

### Search

#### command-suite
```console
$ umbreo blueprint search --keyword |search_keyword| --custom |optional_to_get_custom_or_umbreo_blueprints| --os |all|linux|windows| --page |number_of_page|
```
```console
$ umbreo blueprint search --keyword 'lamp server' --os all
```

#### command-form
```console
$ umbreo blueprint search

1. all
2. linux
3. windows
$ Please choose filter of instance provider? all

$ Search keyword: lamp server
```

#### output
```console
+----+-------------+-------------+-------+-------------+
|                    List Blueprint                    |
+----+-------------+-------------+-------+-------------+
| ID | Name        | Slug        | OS    | Description |
+----+-------------+-------------+-------+-------------+
| 3  | LAMP Server | lamp-server | linux |             |
+----+-------------+-------------+-------+-------------+
```

### Show detail

#### command-suite
```console
$ umbreo blueprint show --id |id_or_slug| --custom |optional_to_get_custom_or_umbreo_blueprints|
```
```console
$ umbreo blueprint show --id lamp-server
```

#### command-form
```console
$ umbreo blueprint show
$ ID or Slug of blueprint: lamp-server
```

#### output
```console
ID: 3
Name: LAMP Server
Description: 
OS: linux
```

### Delete my custom blueprint

Delete bluprient can bse used if a custom blueprint didn't have instance.

#### command-suite
```console
$ umbreo delete --id |id_or_slug|
```
```console
$ umbreo delete --id foo-blueprint
```

#### command-form
```console
$ umbreo blueprint delete
Id or Slug Custom Blueprint: foo-blueprint
```

#### output
```console
Success delete Foo blueprint.
```

### Create custom blueprint

#### command-suite
```console
$ umbreo blueprint create --name |name_blueprint| --operating_system |linux|windows| --system |name_ofsystem| --profile |profiles|
```
```console
$ umbreo blueprint create --name 'foo blueprint' --operating_system linux --system 'Ubuntu 12.04' --profile 'Ruby, Postgresql'
```

#### command-form
```console
$ umbreo blueprint create

$ Name of blueprint: Foo Blueprint

1. linux
2. windows
$ Please choose your blueprint operating system? linux

$ Description: My first blueprint

1. Ubuntu
2. CentOS
3. Fedora
4. Ubuntu 12.04
5. Ubuntu 14.04
6. CentOS 5
7. CentOS 6
8. CentOS 7
9. Fedora 19
10. Fedora 20
11. Ubuntu 10.04
12. Windows
$ Please choose your blueprint system? Ubuntu 10.04

$ Add profiles (call list_profiles to show profiles) eg: 'Ruby, Postgresql': Ruby, Postgresql
```

#### output
```console
Success Create Blueprint - Your Blueprint ID 9 - Use this ID to deploy
```

### Deploy blueprint

### Export blueprint json

#### command-suite
```console
$ umbreo blueprint export --custom |optional_to_get_custom_or_umbreo_blueprints| --id |id_or_name_of_blueprint|
```
```console
$ umbreo blueprint export --custom --id 'foo-blueprint'
```

#### command-form
```console
$ umbreo blueprint export --custom
ID or Slug of Blueprint: foo-blueprint
```

#### output
```console
Success export blueprint. your blueprint is saved on json file with name foo_blueprint.json
```

### Validate blueprint json

#### command-suite
```console
$ umbreo blueprint valid --file |directory_of_json_file|
```
```console
$ umbreo blueprint valid --file foo_blueprint.json
```

#### command-form
```console
$ umbreo blueprint validate
$ Directory of Blueprint: foo_blueprint.json
```

#### output
```console
Success export blueprint. your blueprint is saved on json file with name foo_blueprint.json
```

## 8. Stack Template

All command that's associated to Stack Template

### List or filter

#### command-suite
```console
$ umbreo stack_template list
```

#### output
```console
+---------+---------------------------+----------------------+
|                 List Umbreo Stack Template                 |
+---------+---------------------------+----------------------+
| ID      | Name                      | Blueprints           |
+---------+---------------------------+----------------------+
| 1       | Load Balanced Lamp Server | Apache + MySQL + PHP |
+---------+---------------------------+----------------------+
```

### Search

#### command-suite
```console
$ umbreo stack_template search --keyword |search_keyword|
```
```console
$ umbreo stack_template search --keyword php
```

#### command-form
```console
$ umbreo stack_template search
$ Keyword of Stack Template: php
```

#### output
```console
+--------------+---------------------------+----------------------+
|            List Search Result Umbreo Stack Template             |
+--------------+---------------------------+----------------------+
| ID           | Name                      | Description          |
+--------------+---------------------------+----------------------+
| 1            | Load Balanced Lamp Server | Apache + MySQL + PHP |
+--------------+---------------------------+----------------------+
```

### Show detail

#### command-suite
```console
$ umbreo stack_template show --id |id_or_name|
```
```console
$ umbreo stack_template show --id 'Load Balanced Lamp Server'
```

#### command-form
```console
$ umbreo stack_template show
$ Name or id of Stack Template: Load Balanced Lamp Server
```

#### output
```console
ID: 1
Name: Load Balanced Lamp Server
Description: Apache + MySQL + PHP
+--------------------+---------------------------+--------------------+
|     List Blueprints of Load Balanced Lamp Server stack template     |
+--------------------+---------------------------+--------------------+
| ID Blueprint       | Name                      | Max Server         |
+--------------------+---------------------------+--------------------+
| 26                 | Nginx Webserver           | 1                  |
| 4                  | Apache Webserver with PHP | 1                  |
| 19                 | MySQL Server              | 1                  |
+--------------------+---------------------------+--------------------+
```

### Export stack template json

#### command-suite
```console
$ umbreo stack_template export --id |id_or_name_of_blueprint|
```
```console
$ umbreo stack_template export --id 'Load Balanced Lamp Server'
```

#### command-form
```console
$ umbreo stack_template export
Name or ID of Stack Template: Load Balanced Lamp Server
```

#### output
```console
Success export umbreo stack template. your stack template is saved on json file with name load_balanced_lamp_server.json
```

### Export blueprints of stack template json

#### command-suite
```console
$ umbreo stack_template blueprint_export --id |id_or_name_of_blueprint|
```
```console
$ umbreo stack_template blueprint_export --id 'Load Balanced Lamp Server'
```

#### command-form
```console
$ umbreo stack_template blueprint_export
Name or ID of Stack Template: Load Balanced Lamp Server
```

#### output
```console
Creating JSON Files ...
Success export blueprint. your blueprint is saved on json file with name nginx_webserver.json
Success export blueprint. your blueprint is saved on json file with name apache_webserver_with_php.json
Success export blueprint. your blueprint is saved on json file with name mysql_server.json
JSON Blueprints of 1 stack template already created.
```

## 9. Stack

All command that's associated to Stack

### List

#### command-suite
```console
$ umbreo stack list
```

#### output
```console
+----+----------------+-------------+---------------------------+
|                         List My Stack                         |
+----+----------------+-------------+---------------------------+
| ID | Name           | Description | Umbreo Stack              |
+----+----------------+-------------+---------------------------+
| 1  | Stack One      | test        | Load Balanced Lamp Server |
| 2  | First Stack #1 | test        | Load Balanced Lamp Server |
| 3  | Load Balance   | test        | Load Balanced Lamp Server |
| 4  | test           | test        | Load Balanced Lamp Server |
+----+----------------+-------------+---------------------------+
```

### Search

#### command-suite
```console
$ umbreo stack search --keyword |search_keyword|
```
```console
$ umbreo stack search --keyword 'Stack One'
```

#### command-form
```console
$ umbreo stack search
$ Keyword of Stack: one
```

#### output
```console
+----+----------------+-------------+---------------------------+
|                         List My Stack                         |
+----+----------------+-------------+---------------------------+
| ID | Name           | Description | Umbreo Stack              |
+----+----------------+-------------+---------------------------+
| 1  | Stack One      | test        | Load Balanced Lamp Server |
+----+----------------+-------------+---------------------------+
```

### Show detail

#### command-suite
```console
$ umbreo stack show --id |id_or_name_stack|
```
```console
$ umbreo stack show --id 'Foo Stack'
```

#### command-form
```console
$ umbreo stack show
$ Name or ID of Stack: Foo Stack
```

#### output
```console
ID: 1
Name: Foo Stack
Description: My first stack
Stack Template: Load Balanced Lamp Server
+----------+----------+-------------+
|   List Nodes of Stack One stack   |
+----------+----------+-------------+
| ID       | Name     | Description |
+----------+----------+-------------+
| 81       | FooN1    | test        |
| 82       | FooN2    | test        |
| 83       | FooN3    | test        |
| 84       | FooN4    | test        |
+----------+----------+-------------+
```

### Create stack

```console
$ umbreo stack create --id |id_or_name_stack_template| --name |name_of_stack| --desc |desc_of_stack|
```
```console
$ umbreo stack create --id 1 --name 'Foo Stack' --desc 'My first Foo Stack'

1. yes
2. no
$ Will you add Nginx Webserver? yes
$ Description of new instance: My first node stack
$ Blueprint directory File JSON: /Users/foo/Documents/json/nginx_webserver.json
$ Service logging directory File JSON (optional): 
$ Service monitoring directory File JSON (optional): 
$ Service backup directory File JSON (optional): 

1. test
2. manual
3. provider
$ Please choose deployment type? 3
$ Compute provider directory File JSON: /Users/foo/Documents/json/digital_ocean_provider.json
```

#### output
```console
Stack successfully created.
```

## 10. Cloud Provider

All command that's associated to Stack

### List

#### command-suite
```console
$ umbreo cloud_provider list
```

#### output
```console
+-----+---------------------------+-----------+--------------------------------+
|                             List Cloud Provider                              |
+-----+---------------------------+-----------+--------------------------------+
| ID  | Name                      | Slug      | Description                    |
+-----+---------------------------+-----------+--------------------------------+
| 1   | Amazon Web Services (AWS) | aws       | EC2 Instances                  |
| 2   | Google Compute Engine     | gcompute  | GCE Instances                  |
| 3   | OpenStack                 | openstack | OpenStack IaaS                 |
| 4   | Digital Ocean             | docean    | Digital Ocean will be avail... |
| 6   | Xenserver / XCP           | XenServer | Xenserver / XCP                |
+-----+---------------------------+-----------+--------------------------------+
```

### Export cloud provider json

#### command-suite
```console
$ umbreo cloud_provider export --id |id_or_slug_of_cloud_provider|
```
```console
$ umbreo cloud_provider export --id aws
```

#### command-form
```console
$ umbreo cloud_provider export
$ ID or Slug of Cloud Provider: aws
```

#### output
```console
Success export cloud provider. your cloud_provider is saved on json file with name amazon_web_services(aws).json
```

### Validate cloud provider json

#### command-suite
```console
$ umbreo cloud_provider valid --file |directory_of_json_file|
```
```console
$ umbreo cloud_provider valid --file amazon_web_services(aws).json
```

#### command-form
```console
$ umbreo blueprint validate
$ Directory File JSON: amazon_web_services(aws).json
```

#### output
```console
Validate passed.
```

## 11. Provider

### List or filter

#### command-suite
```console
$ umbreo provider list --cloud |slug_cloud_provider| --page |number_of_page|
```
```console
$ umbreo provider list --cloud all --page 2
```

#### command-form
```console
$ umbreo provider list --page 2

1. all
2. aws
3. gcompute
4. docean
5. openstack
6. XenServer
$ Please choose Cloud Provider filter? all
```

#### output
```console
+---------+-------------+---------------------------+-------------+
|              List My Provider | Page: 2 of 2 pages              |
+---------+-------------+---------------------------+-------------+
| ID      | Name        | Cloud Provider            | Description |
+---------+-------------+---------------------------+-------------+
| 26      | FooPro1     | Digital Ocean             |             |
| 27      | FooPro2     | Digital Ocean             |             |
| 28      | FooPro3     | Digital Ocean             |             |
| 29      | FooPro4     | Digital Ocean             |             |
+---------+-------------+---------------------------+-------------+
```

### Search

#### command-suite
```console
$ umbreo provider search --cloud |slug_cloud_provider| --keyword |search_keyword| --page |number_of_page|
```
```console
$ umbreo provider search --cloud docean --keyword foo
```

#### command-form
```console
$ umbreo provider search

1. all
2. aws
3. gcompute
4. docean
5. openstack
6. XenServer
$ Please choose Cloud Provider filter? docean

$ Search keyword: FooPro1
```

#### output
```console
+---------+-------------+---------------------------+-------------+
|                        List My Provider                         |
+---------+-------------+---------------------------+-------------+
| ID      | Name        | Cloud Provider            | Description |
+---------+-------------+---------------------------+-------------+
| 26      | FooPro1     | Digital Ocean             |             |
+---------+-------------+---------------------------+-------------+
```

### Show detail

#### command-suite
```console
$ umbreo provider show --id |id_or_name|
```
```console
$ umbreo provider show --id 'FooPro1'
```

#### command-form
```console
$ umbreo provider show
$ Name or ID of Provider: FooPro1
```

#### output
```console
ID: 19
Name: FooPro1
Description: 
Cloud provider: Digital Ocean
Created At: 2016-07-01
```

### Create provider

For create provider, we have to export cloud provider json first

#### command-suite
```console
 $ umbreo provider:create |aws|gcompute|docean|openstack|xenserver| --file |directory_of_json_file| --name |provider_name| --desc |provider_description|
```
```console
 $ umbreo provider:create digital_ocean --file digital_ocean.json --name 'Foo Instance'
```

#### command-form
```console
$ umbreo cloud_provider:create digital_ocean 
$ Provider Name: Foo Instance
$ Description (optional): test
$ Directory of File: digital_ocean.json
```

#### output
```console
Creating provider ...
Success create provider
```

### Get Data Credential

For create instance, we need data credential from if we choose provider as deployment type

#### Digital Ocean

Get Images for Digital Ocean Provider

```console
$ umbreo provider:digital_ocean images --id |id_or_name_provider|
```
```console
$ umbreo provider:digital_ocean images --id 'Foo Provider'
```

Get Flavors for Digital Ocean Provider

```console
$ umbreo provider:digital_ocean flavors --id |id_or_name_provider| --image |id_image_digital_ocean_provider|
```
```console
$ umbreo provider:digital_ocean flavors --id 'Foo Provider' --image 18830380
```

Get Regions for Digital Ocean Provider

```console
$ umbreo provider:digital_ocean regions --id |id_or_name_provider| --image |id_image_digital_ocean_provider|
```
```console
$ umbreo provider:digital_ocean regions --id 'Foo Provider' --image 18830380
```

Get Compute Params JSON file

```console
$ umbreo provider:digital_ocean export --id |id_or_name_provider|
```
```console
$ umbreo provider:digital_ocean export --id 'Foo Provider'
```

Check valid Compute Params JSON file

```console
$ umbreo provider:digital_ocean valid --file |directory_of_json_file|
```
```console
$ umbreo provider:digital_ocean valid --file digital_ocean_compute_params.json
```

#### Openstack

Get Zone for Openstack

```console
$ umbreo provider:openstack zones --id |id_or_name_provider|
```
```console
$ umbreo provider:openstack zones --id 'Openstack Foo Provider'
```

Get Flavor for Openstack

```console
$ umbreo provider:openstack flavors --id |id_or_name_provider|
```
```console
$ umbreo provider:openstack flavors --id 'Openstack Foo Provider'
```

Get Image for Openstack

```console
$ umbreo provider:openstack images --id |id_or_name_provider|
```
```console
$ umbreo provider:openstack images --id 'Openstack Foo Provider'
```

Get Group for Openstack

```console
$ umbreo provider:openstack groups --id |id_or_name_provider|
```
```console
$ umbreo provider:openstack groups --id 'Openstack Foo Provider'
```

Get Keypair for Openstack

```console
$ umbreo provider:openstack keypairs --id |id_or_name_provider|
```
```console
$ umbreo provider:openstack keypairs --id 'Openstack Foo Provider'
```

Get Export for Openstack

```console
$ umbreo provider:openstack export --id |id_or_name_provider|
```
```console
$ umbreo provider:openstack export --id 'Openstack Foo Provider'
```

Get Validate for Openstack

```console
$ umbreo provider:openstack valid --file |directory_of_json_file|
```
```console
$ umbreo provider:openstack valid --file openstack_provider.json
```

#### Google Cloud Engine

Get Image for Google Compute Engine

```console
$ umbreo provider:google_ce images --id |id_or_name_provider|
```
```console
$ umbreo provider:google_ce images --id 'GCE Foo Provider'
```

Get Region for Google Compute Engine

```console
$ umbreo provider:google_ce regions --id |id_or_name_provider|
```
```console
$ umbreo provider:google_ce regions --id 'GCE Foo Provider'
```

Get Machine for Google Compute Engine

```console
$ umbreo provider:google_ce machines --id |id_or_name_provider|
```
```console
$ umbreo provider:google_ce machines --id 'GCE Foo Provider'
```

Get Network for Google Compute Engine

```console
$ umbreo provider:google_ce networks --id |id_or_name_provider|
```
```console
$ umbreo provider:google_ce networks --id 'GCE Foo Provider'
```

Get Export for Google Compute Engine

```console
$ umbreo provider:google_ce export --id |id_or_name_provider|
```
```console
$ umbreo provider:google_ce export --id 'GCE Foo Provider'
```

Get Validate for Google Compute Engine

```console
$ umbreo provider:google_ce valid --file |directory_of_json_file|
```
```console
$ umbreo provider:google_ce valid --file google_compute_engine_service_provider.json
```

#### Amazon Web Service

Get Images for AWS Provider

```console
$ umbreo provider:amazon_web_service images --id |id_or_name_provider|
```
```console
$ umbreo provider:amazon_web_service images --id 'AWS Foo Provider'
```

Get Size Storage for AWS Provider

```console
$ umbreo provider:amazon_web_service sizes --id |id_or_name_provider|
```
```console
$ umbreo provider:amazon_web_service sizes --id 'AWS Foo Provider'
```

Get Region for AWS Provider

```console
$ umbreo provider:amazon_web_service regions --id |id_or_name_provider|
```
```console
$ umbreo provider:amazon_web_service regions --id 'AWS Foo Provider'
```

Get Keypair for AWS Provider

```console
$ umbreo provider:amazon_web_service keypairs --id |id_or_name_provider|
```
```console
$ umbreo provider:amazon_web_service keypairs --id 'AWS Foo Provider'
```

Get Security Group for AWS Provider

```console
$ umbreo provider:amazon_web_service security_groups --id |id_or_name_provider|
```
```console
$ umbreo provider:amazon_web_service security_groups --id 'AWS Foo Provider'
```

Get Compute Params JSON file

```console
$ umbreo provider:amazon_web_service export --id |id_or_name_provider|
```
```console
$ umbreo provider:amazon_web_service export --id 'AWS Foo Provider'
```

Check valid Compute Params JSON file

```console
$ umbreo provider:amazon_web_service valid --file |directory_of_json_file|
```
```console
$ umbreo provider:amazon_web_service valid --file amazon_web_service_compute_params.json
```

## 12. Service Provider

### List or filter

#### command-suite
```console
$ umbreo service_provider list --type |all|logging|monitoring|backup| --resource |all|master|client| --page |number_of_page|
```
```console
$ umbreo service_provider list --type all --resource all
```

#### command-form
```console
$ umbreo service_provider list

1. all
2. logging
3. monitoring
4. backup
$ Please choose filter of service provider type? all

1. all
2. master
3. client
$ Please choose filter of resource? all
```

#### output
```console
+----+----------------+---------------+--------------+---------------+
|                       List Service Provider                        |
+----+----------------+---------------+--------------+---------------+
| ID | Name           | Resource Type | Service Type | Slug          |
+----+----------------+---------------+--------------+---------------+
| 1  | baculaserver   | master        | backup       | baculaserver  |
| 2  | graylog2       | master        | logging      | graylog2      |
| 3  | nagios::server | master        | monitoring   | nagios-server |
| 4  | zabbix         | master        | monitoring   | zabbix        |
+----+----------------+---------------+--------------+---------------+
```

### Search

#### command-suite
```console
$ umbreo service_provider search --keyword |search_keyword| --type |all|logging|monitoring|backup| --resource |all|master|client| --page |number_of_page|
```
```console
$ umbreo service_provider search --keyword bacula --type all --resource all
```

#### command-form
```console
$ umbreo service_provider search

1. all
2. logging
3. monitoring
4. backup
$ Please choose filter of service provider type? all

1. all
2. master
3. client
$ Please choose filter of resource? all

$ Search Keyword: bacula
```

#### output
```console
+----+----------------+---------------+--------------+---------------+
|                       List Service Provider                        |
+----+----------------+---------------+--------------+---------------+
| ID | Name           | Resource Type | Service Type | Slug          |
+----+----------------+---------------+--------------+---------------+
| 1  | baculaserver   | master        | backup       | baculaserver  |
+----+----------------+---------------+--------------+---------------+
```

### Show detail

#### command-suite
```console
$ umbreo service_provider show --id |id_or_name|
```
```console
$ umbreo service_provider show --id baculaserver
```

#### command-form
```console
$ umbreo cloud_provider show
$ Name or ID of Service Provider: baculaserver
```

#### output
```console
ID: 1
Name: baculaserver
Resource type: master
Service Type: backup
Slug: baculaserver
Description: bacula backup client
```

### Export service provider json

#### command-suite
```console
$ umbreo service_provider export --id |id_or_name|
```
```console
$ umbreo service_provider export --id baculaserver
```

#### command-form
```console
$ umbreo cloud_provider export
$ Name or ID of Service provider: baculaserver
```

#### output
```console
Success export umbreo service provider. your service provider is saved on json file with name baculaserver.json
```

### Validate service provider json

#### command-suite
```console
$ umbreo service_provider valid --file |directory_of_json_file|
```
```console
$ umbreo service_provider valid --file baculaserver.json
```

#### command-form
```console
$ umbreo service_provider validate
$ Directory of Service Provider: baculaserver.json
```

#### output
```console
Validate passed. You can deploy now
```

## 13. Service

All command that's associated to Service

### List or filter

#### command-suite
```console
$ umbreo service list --state |all|active|nonactive| --type |optional_id_or_slug_service_provider| --page |number_of_page|
```
```console
$ umbreo service list --state all --type baculaserver
```

#### command-form
```console
$ umbreo service list

1. all
2. active
3. unactive
$ Please choose filter of state service? all

$ ID or Slug of Service provider: baculaserver
```

#### output
```console
+----+-----------------+------------------+------------+--------+
|                         List Service                          |
+----+-----------------+------------------+------------+--------+
| ID | Name            | Service Provider | Link Type  | Active |
+----+-----------------+------------------+------------+--------+
| 1  | BaculaExternal  | baculaserver     | external   | Yes    |
| 2  | BaculaServer    | baculaserver     | new_server | Yes    |
| 3  | First #1        | baculaserver     | external   | Yes    |
+----+-----------------+------------------+------------+--------+
```

### Search

#### command-suite
```console
$ umbreo service search --keyword |search_keyword| --state |all|active|nonactive| --type |optional_id_or_slug_service_provider| --page |number_of_page|
```
```console
$ umbreo service search --keyword 'BaculaExternal' --state all --type baculaserver
```

#### command-form
```console
$ umbreo service search

1. all
2. active
3. unactive
$ Please choose filter of state service? 1

$ ID or Slug of Service provider: baculaserver

$ Search keyword: BaculaExternal
```

#### output
```console
+----+-----------------+------------------+------------+--------+
|                         List Service                          |
+----+-----------------+------------------+------------+--------+
| ID | Name            | Service Provider | Link Type  | Active |
+----+-----------------+------------------+------------+--------+
| 1  | BaculaExternal  | baculaserver     | external   | Yes    |
+----+-----------------+------------------+------------+--------+
```

### Show detail

#### command-suite
```console
$ umbreo service show --id |id_or_name|
```
```console
$ umbreo service show --id 'BaculaExternal'
```

#### command-form
```console
$ umbreo service show
$ Name or ID of Service: BaculaExternal
```

#### output
```console
ID: 1
Name: BaculaExternal
Service Provider: baculaserver
Link type: external
Active: Yes
Description: My first Bacula
```

### Create Service

#### command
```console
$ umbreo service create --external |optional_to_choose_external| --file |directory_of_json_file| --id |service_template_id_or_slug| --name |name_of_service| --desc |description_for_service|
```
```console
$ umbreo service create --external --file baculaclient.json --id bacula --name 'Foo Service' --desc 'My first foo service'
```

### Export service json

#### command-suite
```console
$ umbreo service export --id |id_or_name|
```
```console
$ umbreo service export --id 'BaculaExternal'
```

#### command-form
```console
$ umbreo service export
$ Name or ID of Service: BaculaExternal
```

#### output
```console
Success export service. your service is saved on json file with name baculaexternal.json
```

### Validate service json

#### command-suite
```console
$ umbreo service valid --file |directory_of_json_file|
```
```console
$ umbreo service valid --file baculaexternal.json
```

#### command-form
```console
$ umbreo service validate
$ Directory of Service Provider: baculaexternal.json
```

#### output
```console
Validate passed. You can deploy now
```

# Help Command To Get Started
### For some reason you might be confuse to get started with CLI, you can simply run this command to get help
```console
umbreo help
```

